﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Reflection;

namespace Filter_Sort_BusinessObject
{
    public partial class Form1 : Form
    {
        List<MyPerson> people;
        Bitmap _sortup, _sortdn;
        public Form1()
        {
            InitializeComponent();
            people = new List<MyPerson>();

            #region "Add Data"
            people.Add(new MyPerson(1, "Ron"));
            people.Add(new MyPerson(2, "Liv"));
            people.Add(new MyPerson(3, "Greg"));
            people.Add(new MyPerson(4, "Steve"));
            people.Add(new MyPerson(5, "John"));
            people.Add(new MyPerson(6, "Dan"));
            people.Add(new MyPerson(7, "Frederick"));
            people.Add(new MyPerson(8, "Greg"));
            people.Add(new MyPerson(9, "Robert"));
            people.Add(new MyPerson(10, "Patrick"));
            #endregion

            //Bind the grid to the list object.
            c1TrueDBGrid1.SetDataBinding(people, "");
            //We'd handle sort & Filter ourselves
            c1TrueDBGrid1.AllowSort = false;
            c1TrueDBGrid1.AllowFilter = false;

            // get the sorting indicators that we'll use in the column headers            
            _sortdn  = new Bitmap("..\\..\\SortDn.bmp");
            _sortup = new Bitmap("..\\..\\SortUp.bmp");
            _sortdn.MakeTransparent(Color.Red);
            _sortup.MakeTransparent(Color.Red);            
        }

        //Booelan flags
        bool col1_Asc = false;
        bool col2_Asc = false;

        private void c1TrueDBGrid1_HeadClick(object sender, C1.Win.C1TrueDBGrid.ColEventArgs e)
        {
            try
            {
                if (e.Column.Name == "ID")
                {
                    if (!col2_Asc)
                    {
                        people.Sort(delegate(MyPerson mp1, MyPerson mp2) { return mp1.ID.CompareTo(mp2.ID); });
                        col2_Asc = true;
                        this.c1TrueDBGrid1.Splits[0].DisplayColumns["ID"].HeadingStyle.ForegroundImage = this._sortup;
                    }
                    else if (col2_Asc)
                    {
                        people.Sort(delegate(MyPerson mp1, MyPerson mp2) { return mp2.ID.CompareTo(mp1.ID); });
                        col2_Asc = false;
                        this.c1TrueDBGrid1.Splits[0].DisplayColumns["ID"].HeadingStyle.ForegroundImage = this._sortdn;
                    }                                       
                    //Remove Sort Glyph from other column.
                    this.c1TrueDBGrid1.Splits[0].DisplayColumns["Name"].HeadingStyle.ForegroundImage = null;
                }

                if (e.Column.Name == "Name")
                {
                    if (!col1_Asc)
                    {
                        people.Sort(delegate(MyPerson mp1, MyPerson mp2) { return mp1.Name.CompareTo(mp2.Name); });
                        col1_Asc = true;
                        this.c1TrueDBGrid1.Splits[0].DisplayColumns["Name"].HeadingStyle.ForegroundImage = this._sortup;
                    }
                    else if (col1_Asc)
                    {
                        people.Sort(delegate(MyPerson mp1, MyPerson mp2) { return mp2.Name.CompareTo(mp1.Name); });
                        col1_Asc = false;
                        this.c1TrueDBGrid1.Splits[0].DisplayColumns["Name"].HeadingStyle.ForegroundImage = this._sortdn;
                    }
                    //Remove Sort Glyph from other column.
                    this.c1TrueDBGrid1.Splits[0].DisplayColumns["ID"].HeadingStyle.ForegroundImage = null;
                } 

                //Set SortGlyph's position in Column Header
                foreach (C1.Win .C1TrueDBGrid .C1DisplayColumn dc in this.c1TrueDBGrid1 .Splits [0].DisplayColumns )
                    dc.HeadingStyle.ForeGroundPicturePosition = C1.Win.C1TrueDBGrid.ForeGroundPicturePositionEnum.RightOfText;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message);
            }
            finally
            {
                c1TrueDBGrid1.Rebind(true);
            }
        }

        private void button1_Click(object sender, EventArgs e)
        {
            string id = this.txtID .Text ;
            string name = this.txtName.Text;
            //Create a new list object; to be populated with filtered values.
            List<MyPerson> p = new List<MyPerson>();
            try
            {
                if (id != "" && name != "")
                {
                    MyPerson _p = new MyPerson(int.Parse(id), name);
                    p = people.FindAll(delegate(MyPerson mp) { return (mp.ID == _p.ID && mp.Name == _p.Name); });
                }
                else if (id != "" && name == "")
                {
                    p = people.FindAll(delegate(MyPerson mp) { return (mp.ID == int.Parse(id)); });
                }
                else if (id == "" && name != "")
                {
                    p = people.FindAll(delegate(MyPerson mp) { return (mp.Name == name); });
                }

            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message);
            }
            finally
            {
                //bind the grid to the actual list object if both textboxes are blank.
                if (id == "" && name == "")
                {
                    c1TrueDBGrid1.SetDataBinding(people, "", true);
                }
                //else bind the grid to the new list object containing filtered values.   
                else
                {
                    c1TrueDBGrid1.SetDataBinding(p, "", true);
                }
            }
        }
    }
    
    public class MyPerson
    {
        public int ID { get; set; }
        public string Name { get; set; }
        
        public MyPerson(int id, string name)
        {
            ID = id;
            Name = name;            
        }
    }
}
